@@ -1,7 +1,6 @@
 function Reset()
 {
-  TargetInterface.pokeByte(0xFFFF0230, 4); // RSTSTA - Software reset
-  TargetInterface.setICEBreakerBreakpoint(0, 0x00080000, 0x00000000, 0x00000000, 0xFFFFFFFF, 0x100, 0xF7);
+  TargetInterface.setICEBreakerBreakpoint(0, 0x00000000, 0xFFFFFFFF, 0x00000000, 0xFFFFFFFF, 0x100, 0xF7);
   TargetInterface.waitForDebugState(1000);
   TargetInterface.trst();
 }
@@ -15,6 +14,7 @@ function SRAMReset()
 function FLASHReset()
 {
   Reset();
+  TargetInterface.pokeByte(0xFFFF0220, 0); // REMAP - Map FLASH to 0x00000000
 }
 
 
